[−][src]Module cryptsetup_rs::api
High-level API to work with libcryptsetup supported devices (disks)
The main focus is on LUKS1 and LUKS2 devices
Re-exports
pub use crate::device::Error; |
pub use crate::device::Keyslot; |
pub use crate::device::Luks2TokenHandler; |
pub use crate::device::Luks2TokenHandlerBox; |
pub use crate::device::Luks2TokenHandlerRaw; |
pub use crate::device::Luks2TokenId; |
pub use crate::device::Result; |
Structs
| CryptDeviceFormatBuilder | Struct containing state for the |
| CryptDeviceHandle | An opaque handle on an initialized crypt device |
| CryptDeviceLuks2FormatBuilder | |
| CryptDeviceOpenBuilder | Struct containing state for the |
| Luks2Metadata | |
| Luks2Token |
Enums
| crypt_pbkdf_algo_type | |
| crypt_token_info |
Traits
| CryptDevice | Trait representing common operations on a crypt device |
| CryptDeviceType | Trait for querying the device type at runtime |
| Luks1CryptDevice | Trait representing specific operations on a LUKS1 device |
| Luks2CryptDevice | Trait representing specific operations on a LUKS2 device |
| LuksCryptDevice |
Functions
| enable_debug | Enable internal |
| format | Builder to format a crypt device at the specified path |
| luks1_uuid | Deprecated Read the UUID of a LUKS1 container without opening the device |
| luks_uuid | Read the LUKS version used by a LUKS container without opening the device |
| luks_version | Read the LUKS version used by a LUKS container without opening the device |
| open | Builder to open a crypt device at the specified path |
Type Definitions
| Luks1CryptDeviceHandle | |
| Luks2CryptDeviceHandle |