[][src]Function cryptsetup_rs::device::luks2_register_token_handler

pub fn luks2_register_token_handler<H: Luks2TokenHandlerRaw>(
    handler_box: &Luks2TokenHandlerBox<H>
) -> Result<()>

Register a LUKS2 token handler

Note: the implementation relies on a struct with a box containing the actual handler C struct. The handler C struct must not be deallocated while the handler is registered.