[−][src]Module cryptsetup_rs::device
Low-level cryptsetup binding that sits directly on top of the libcryptsetup C API
Consider using the high-level binding in the api module instead
Enums
| Error |
Functions
| cipher | Get the cipher used by this crypt device |
| cipher_mode | Get the cipher mode used by this crypt device |
| cryptsetup_rs_log_callback | Log function callback used by |
| device_name | Get the path to the device (as |
| dump | Dump text-formatted information about this device to the console |
| enable_debug | Enable internal |
| free | Releases crypt device context and memory |
| init | Initialise crypt device and check if provided device exists |
| keyslot_status | Get information about a keyslot |
| load | Load crypt device parameters from the on-disk header |
| luks1_format | Format a new crypt device but do not activate it |
| luks_activate | Activate device based on provided key ("passphrase") |
| luks_add_keyslot | Add key slot using provided passphrase. If there is no previous passphrase, use the volume key that is in-memory to add the new key slot. |
| luks_destroy_keyslot | Destroy (and disable) key slot |
| luks_update_keyslot | Add key slot using provided passphrase. |
| rng_type | Get which RNG is used |
| set_iteration_time | Set the number of milliseconds for |
| set_rng_type | Set which RNG is used |
| uuid | Get device UUID |
| volume_key_size | Get size in bytes of the volume key |
Type Definitions
| Keyslot | |
| RawDevice | Raw pointer to the underlying |
| Result |